ConnectionPool

Struct ConnectionPool 

pub struct ConnectionPool<S> { /* private fields */ }
Connection pool

ConnectionPool holds reusable connections. A reusable connection is released to this pool to be picked up by another user/request.

Implementations

Source

impl<S> ConnectionPool<S>

pub fn new(size: usize) -> Self

Create a new ConnectionPool with a global size limit.

When a connection is released to this pool and total occupancy is at or above size, the least recently used connection is dropped.

pub fn pop_closed(&self, meta: &ConnectionMeta)

pub fn get(&self, key: &u64) -> Option<S>

Get a connection from this pool under the same group key

pub fn put( &self, meta: &ConnectionMeta, connection: S, ) -> (Arc<Notify>, Receiver<bool>)

Release a connection to this pool for reuse

pub async fn idle_poll<Stream>( &self, connection: OwnedMutexGuard<Stream>, meta: &ConnectionMeta, timeout: Option<Duration>, notify_evicted: Arc<Notify>, watch_use: Receiver<bool>, ) -> bool
where Stream: AsyncRead + Unpin + Send,

Actively monitor the health of a connection that is already released to this pool

When the connection breaks, or the optional timeout is reached this function will remove it from the pool and drop the connection.

If the connection is reused via Self::get() or being evicted, this function will just exit.

Returns true if the connection was evicted from the pool, and false otherwise.

pub async fn idle_timeout( &self, meta: &ConnectionMeta, timeout: Option<Duration>, notify_evicted: Arc<Notify>, notify_closed: Receiver<bool>, watch_use: Receiver<bool>, ) -> bool

Passively wait to close the connection after the timeout

If this connection is not being picked up or evicted before the timeout is reach, this function will remove it from the pool and close the connection.

Returns true if the connection was evicted from the pool, and false otherwise.